# 首充客户端文档

## 目录
- [功能概述](#功能概述)
- [特性](#特性)
- [核心数据结构](#核心数据结构)
- [核心方法](#核心方法)
- [组件引用](#组件引用)  
- [风险提示](#风险提示)
- [QA](#qa)
- [使用示例](#使用示例)

## 功能概述
本模块提供游戏首充功能相关接口，包含：
- 首充商品购买流程
- 每日奖励领取功能
- 首充界面展示与控制
- 与服务器端的RPC通信

## 特性
- 支持多档位首充配置
- 自动同步服务器状态
- 可视化奖励倒计时
- 红点提示系统集成
- 多语言支持

## 核心数据结构

### BuyParam
```typescript
class BuyParam {
  cmId: number;    // 商品ID
  shopId: number;  // 商店ID
  buyNum: number;  // 购买数量
}
```

### AwardParam 
```typescript
class AwardParam {
  id: number;     // 奖励ID
  dayId: number;  // 领取天数
}
```

### ShopItemCfg
```typescript
interface ShopItemCfg {
  id: number;
  price: number;      // 价格(分)
  logicCoin: number;  // 虚拟币数量
  recharge_id: number;// 关联充值ID
}
```

## 核心方法

### FristRechargeRpc
| 方法 | 参数 | 返回值 | 说明 |
|------|------|--------|------|
| `buy(id: number)` | id: 商品ID | Promise\<void> | 执行首充购买 |
| `getAwards(id: number, dayId: number)` | id: 奖励ID<br>dayId: 领取天数 | Promise\<boolean> | 领取每日奖励 |

### PageDataMgr
| 方法 | 说明 |
|------|------|
| `getRechargeList()` | 获取可购买首充列表 |
| `getRechargeAwardInfo(id: number)` | 获取指定商品的奖励信息 |

### 工具方法
```typescript
openFristRecharge(props?: Object, group = 'cover')  // 打开首充界面
```

## 组件引用
Vue文件中使用的game_*组件：

| 组件路径 | 用途 |
|---------|------|
| `game_ui_scene/ui_scene.vue` | 3D场景渲染 |
| `game_time_cd/timer_cd.vue` | 倒计时组件 |
| `game_btn_text/text_btn.vue` | 文本按钮组件 |
| `game_prop_item/prop_item.vue` | 道具展示组件 |
| `game_red_point/red_point.vue` | 红点提示组件 |
| `game_widget_bottom_tab/base.vue` | 底部选项卡组件 |

## 风险提示
1. 价格单位转换需注意除100操作（`price/100`）
2. 时间计算依赖DateMgr服务时间同步
3. 配置加载失败需处理getCfg返回null情况
4. 网络请求需处理ERR13等错误码

## QA
**Q：购买后奖励未及时刷新？**  
A：调用initData()手动刷新数据

**Q：倒计时显示异常？**  
A：检查DateMgr服务时间同步状态

**Q：红点提示不消失？**  
A：确认redKey与nodeId组合唯一性

## 使用示例

```typescript
// 打开首充界面
openFristRecharge();

// 购买首充
FristRechargeRpc.buy(1001).then(success => {
  if(success) console.log("购买成功");
});

// 领取奖励
FristRechargeRpc.getAwards(1001, 1).then(claimed => {
  if(claimed) console.log("奖励已领取");
});
