import { open } from "game_root/client/root";
import { DateMgr } from "pi_business_tool/date_mgr";
import { encodeKey } from "pi_network/gate_way/util";
import { Network } from "pi_network/client_net/network";
import { CommonNumberTool } from "game_common/num_tools";
import { clientRpc } from "pi_network/client_net/net_env";
import { getCfg, getAllCfg } from "pi_common_tools/util/db_tool";
import { openCongratulation } from "game_congratulation_award/base";
import { BuyParam } from "game_common_shop_server/struct/common_shop.struct";
import { AwardParam } from "game_series_get_server/struct/series_get.struct";
import { ShopItemCfg } from "game_common_shop_server/xls/common_shop/shop_item.struct";
import { awardPopup, getPopupInfo } from 'game_series_get_server/rpc/series_get.event';


import { MallRelationCfg } from "game_series_get_server/cfg/series_get/relation.struct";
import { getCommonShopRpc, commonShopBuyRpc } from "game_common_shop_server/rpc/common_shop.event";
import { FIRST_PAY_GROUPS, FIRST_PAY, ERR13 } from "game_common_shop_server/xls/common_shop/shop_base.struct";

import VueFristRechage from "./main.vue";
import { getCurrentRid } from "pi_common_tools/main";
import { EMsgCode } from "game_rpc_result/base/constant";
import { showTopTips } from "game_show_top_tips/common_tips";
import { AwardDBURL } from "game_frist_recharge_client/xls/base/base.struct";
import { openRechargeTips } from "game_widget_window_client/widget/goods_tips";

export type AsyncReturnType<T> = T extends (...args: any[]) => Promise<infer U> ? U : any;

export class FristRechargeRpc {

    /**
     * 购买首充
     * @param id 首充Id
     * @returns 
     */
    public static async buy(id: number) {
        const tehuiCfg: ShopItemCfg = getCfg(ShopItemCfg._$info.name, id) as any;
        openRechargeTips([tehuiCfg.logicCoin, tehuiCfg.price / 100], {
            count: 1,
            goodsNum: 1,
            isCard: false,
            goodsId: tehuiCfg.id + '',
            rechargeId: tehuiCfg.recharge_id
        }, async () => {
            let param = new BuyParam();
            param.cmId = id;
            param.shopId = FIRST_PAY;
            param.buyNum = 1;
            const res = await clientRpc(commonShopBuyRpc._$topic as any, param);
            if (res === ERR13) {
                return false;
            } else if (Array.isArray(res)) {
                if (res.length > 0) openCongratulation(res);
                return true;
            }
            showTopTips(res)
            return false;
        })
    }

    /**
     * 领取首充每日奖励
     * @param id 首充Id
     * @returns 
     */
    public static async getAwards(id: number, dayId: number) {
        const param = new AwardParam();
        param.id = id;
        param.dayId = dayId;
        const res = await clientRpc(awardPopup._$topic, param);
        if (res && Array.isArray(res)) {
            openCongratulation(res);
            return true;
        }
        if (EMsgCode[res]) showTopTips(EMsgCode[res]);
        return false;
    }
}


export class PageDataMgr {

    /**
     * 获取首充列表
     * @returns 
     */
    public static async getRechargeList() {
        const ids = JSON.parse(FIRST_PAY_GROUPS) as number[];
        const info = await clientRpc(getCommonShopRpc._$topic, FIRST_PAY);
        const buyMap = info?.pcsDB?.buyMap || new Map();
        return ids.filter((v, i) => {
            const item = buyMap.get(ids[0]);
            return i === 0 || !!item;
        }).map(v => {
            const tehuiCfg: ShopItemCfg = getCfg(ShopItemCfg._$info.name, v) as any;
            return {
                id: v,
                price: tehuiCfg.price,
                redItem: {
                    redKey: v,
                    nodeId: 'frist_recharge'
                },
                text: (tehuiCfg.price / 100) + '元'
            }
        })
    }

    /**
     * 获取首充奖励信息
     * @param id 首充Id
     * @returns 
     */
    public static async getRechargeAwardInfo(id: number) {
        const tehuiCfg: ShopItemCfg = getCfg(ShopItemCfg._$info.name, id) as any;
        const info = await clientRpc(getPopupInfo._$topic);
        const item = info?.get(id);
        const cfg = (item ? item.cfg : getCfg(MallRelationCfg._$info.name, id)) as MallRelationCfg;
        const temp = item ? item.dayTmp : 0;
        const now = DateMgr.now();
        const zeroTime = DateMgr.dailyZero(now);
        return {
            id,
            isBuy: !!item,
            price: tehuiCfg.price,
            showPrice: (tehuiCfg.price / 100) + '元',
            canGet: item ? item.dayAward : false,
            textIcon: tehuiCfg.icon,
            desc: tehuiCfg.desc,
            list: (<[number, number][][]>cfg.awards).map((v, i) => {
                const endTime = item ? (i + 1) > temp ? (zeroTime + DateMgr.OneDayMs * (i + 1 - temp)) : 0 : 0;
                const isGet = item ? ((temp > i + 1) || ((temp === i + 1) && !item.dayAward)) : false;
                return {
                    awards: v,
                    dayId: i + 1,
                    state: isGet ? 2 : item && now >= endTime ? 1 : 0,
                    text: `第${CommonNumberTool.convertToChinese(i + 1, false)}天`,
                    endTime: item ? (i + 1) > temp ? (zeroTime + DateMgr.OneDayMs * (i + 1 - temp)) : 0 : 0
                }
            })
        }
    }
}

export const openFristRecharge = (props?: Object, group = 'cover') => {
    open(VueFristRechage, props, group);
}

export const __init = () => {
    const rlMap = getAllCfg(MallRelationCfg) as Map<number, MallRelationCfg>;
    Network.subMore(Array.from(rlMap || new Map()).map(v => {
        const urlKey = v[1].eventURL + v[1].id;
        const primaryKey = urlKey + '_' + getCurrentRid();
        return {
            subStruct: null,
            primaryKey: `logfile.${AwardDBURL}.${encodeKey(primaryKey)}`
        }
    }))
}